ExOnvif (ExOnvif v0.9.0)
View SourceInterface for making requests to an Onvif compatible device.
Currently supports WS Discovery probing, a subset of Device wsdl functions and a subset of Media wsdl functions.
Summary
Types
@type error() :: {:error, ExOnvif.Fault.t()} | {:error, %{status: non_neg_integer(), response: any()}}