ExOnvif (ExOnvif v0.8.0)

Interface for making requests to an Onvif compatible device.

Currently supports WS Discovery probing, a subset of Device wsdl functions and a subset of Media wsdl functions.